<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.log_monitor.log_widget`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**
- **db_conn_name**
- **command_palette_available**


---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L15"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogMonitorWidget`




<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L16"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorWidget.__init__`

```python
__init__(parent=None)
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L38"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorWidget.open_profile_prompt`

```python
open_profile_prompt()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L51"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorWidget.query_existing_loggers`

```python
query_existing_loggers()
```






---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L60"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogMonitorDockWidget`




<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L61"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDockWidget.__init__`

```python
__init__(parent=None)
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDockWidget.adjust_size`

```python
adjust_size()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDockWidget.toggleViewAction`

```python
toggleViewAction()
```






---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L93"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogMonitorDropdown`




<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L94"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDropdown.__init__`

```python
__init__(parent=None)
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L122"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDropdown.center_on_parent`

```python
center_on_parent()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L109"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDropdown.toggleViewAction`

```python
toggleViewAction()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_widget.py#L115"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogMonitorDropdown.toggle_view`

```python
toggle_view()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
